pub fn annotation_queues_create_queue_assignment<'f1, 'f2>() -> AnnotationQueuesCreateQueueAssignmentBuilder<'f1, 'f2>Expand description
Create an assignment for a user to an annotation queue
pub fn annotation_queues_create_queue_assignment<'f1, 'f2>() -> AnnotationQueuesCreateQueueAssignmentBuilder<'f1, 'f2>Create an assignment for a user to an annotation queue