pub fn annotation_queues_delete_queue_assignment<'f1, 'f2>() -> AnnotationQueuesDeleteQueueAssignmentBuilder<'f1, 'f2>Expand description
Delete an assignment for a user to an annotation queue
pub fn annotation_queues_delete_queue_assignment<'f1, 'f2>() -> AnnotationQueuesDeleteQueueAssignmentBuilder<'f1, 'f2>Delete an assignment for a user to an annotation queue