Module dataset_items_api

Module dataset_items_api 

Structs

DatasetItemsCreateBuilder
Use builder syntax to set the inputs and finish with call().
DatasetItemsDeleteBuilder
Use builder syntax to set the inputs and finish with call().
DatasetItemsGetBuilder
Use builder syntax to set the inputs and finish with call().
DatasetItemsListBuilder
Use builder syntax to set the inputs and finish with call().

Enums

DatasetItemsCreateError
struct for typed errors of method dataset_items_create
DatasetItemsDeleteError
struct for typed errors of method dataset_items_delete
DatasetItemsGetError
struct for typed errors of method dataset_items_get
DatasetItemsListError
struct for typed errors of method dataset_items_list

Functions

dataset_items_create
Create a dataset item
dataset_items_delete
Delete a dataset item and all its run items. This action is irreversible.
dataset_items_get
Get a dataset item
dataset_items_list
Get dataset items. Optionally specify a version to get the items as they existed at that point in time. Note: If version parameter is provided, datasetName must also be provided.