Module datasets_api

Module datasets_api 

Structs

DatasetsCreateBuilder
Use builder syntax to set the inputs and finish with call().
DatasetsDeleteRunBuilder
Use builder syntax to set the inputs and finish with call().
DatasetsGetBuilder
Use builder syntax to set the inputs and finish with call().
DatasetsGetRunBuilder
Use builder syntax to set the inputs and finish with call().
DatasetsGetRunsBuilder
Use builder syntax to set the inputs and finish with call().
DatasetsListBuilder
Use builder syntax to set the inputs and finish with call().

Enums

DatasetsCreateError
struct for typed errors of method datasets_create
DatasetsDeleteRunError
struct for typed errors of method datasets_delete_run
DatasetsGetError
struct for typed errors of method datasets_get
DatasetsGetRunError
struct for typed errors of method datasets_get_run
DatasetsGetRunsError
struct for typed errors of method datasets_get_runs
DatasetsListError
struct for typed errors of method datasets_list

Functions

datasets_create
Create a dataset
datasets_delete_run
Delete a dataset run and all its run items. This action is irreversible.
datasets_get
Get a dataset
datasets_get_run
Get a dataset run and its items
datasets_get_runs
Get dataset runs
datasets_list
Get all datasets