Module models_api

Module models_api 

Structs

ModelsCreateBuilder
Use builder syntax to set the inputs and finish with call().
ModelsDeleteBuilder
Use builder syntax to set the inputs and finish with call().
ModelsGetBuilder
Use builder syntax to set the inputs and finish with call().
ModelsListBuilder
Use builder syntax to set the inputs and finish with call().

Enums

ModelsCreateError
struct for typed errors of method models_create
ModelsDeleteError
struct for typed errors of method models_delete
ModelsGetError
struct for typed errors of method models_get
ModelsListError
struct for typed errors of method models_list

Functions

models_create
Create a model
models_delete
Delete a model. Cannot delete models managed by Langfuse. You can create your own definition with the same modelName to override the definition though.
models_get
Get a model
models_list
Get all models