pub fn models_delete<'f1, 'f2>() -> ModelsDeleteBuilder<'f1, 'f2>Expand description
Delete a model. Cannot delete models managed by Langfuse. You can create your own definition with the same modelName to override the definition though.
pub fn models_delete<'f1, 'f2>() -> ModelsDeleteBuilder<'f1, 'f2>Delete a model. Cannot delete models managed by Langfuse. You can create your own definition with the same modelName to override the definition though.