Module scores_api

Module scores_api 

Structs

ScoresGetByIdBuilder
Use builder syntax to set the inputs and finish with call().
ScoresGetManyBuilder
Use builder syntax to set the inputs and finish with call().

Enums

ScoresGetByIdError
struct for typed errors of method scores_get_by_id
ScoresGetManyError
struct for typed errors of method scores_get_many

Functions

scores_get_by_id
Get a score (supports both trace and session scores)
scores_get_many
Get a list of scores (supports both trace and session scores)