Module trace_api

Module trace_api 

Structs

TraceDeleteBuilder
Use builder syntax to set the inputs and finish with call().
TraceDeleteMultipleBuilder
Use builder syntax to set the inputs and finish with call().
TraceGetBuilder
Use builder syntax to set the inputs and finish with call().
TraceListBuilder
Use builder syntax to set the inputs and finish with call().

Enums

TraceDeleteError
struct for typed errors of method trace_delete
TraceDeleteMultipleError
struct for typed errors of method trace_delete_multiple
TraceGetError
struct for typed errors of method trace_get
TraceListError
struct for typed errors of method trace_list

Functions

trace_delete
Delete a specific trace
trace_delete_multiple
Delete multiple traces
trace_get
Get a specific trace
trace_list
Get list of traces