BlobStorageIntegrationResponseBuilder

Struct BlobStorageIntegrationResponseBuilder 

pub struct BlobStorageIntegrationResponseBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> BlobStorageIntegrationResponseBuilder<S>

pub fn build(self) -> BlobStorageIntegrationResponse
where S: IsComplete,

Finish building and return the requested object

pub fn id( self, value: String, ) -> BlobStorageIntegrationResponseBuilder<SetId<S>>
where S::Id: IsUnset,

Required.

pub fn project_id( self, value: String, ) -> BlobStorageIntegrationResponseBuilder<SetProjectId<S>>
where S::ProjectId: IsUnset,

Required.

pub fn type( self, value: BlobStorageIntegrationType, ) -> BlobStorageIntegrationResponseBuilder<SetType<S>>
where S::Type: IsUnset,

Required.

pub fn bucket_name( self, value: String, ) -> BlobStorageIntegrationResponseBuilder<SetBucketName<S>>
where S::BucketName: IsUnset,

Required.

pub fn endpoint( self, value: Option<String>, ) -> BlobStorageIntegrationResponseBuilder<SetEndpoint<S>>
where S::Endpoint: IsUnset,

Optional (Some / Option setters).

pub fn maybe_endpoint( self, value: Option<Option<String>>, ) -> BlobStorageIntegrationResponseBuilder<SetEndpoint<S>>
where S::Endpoint: IsUnset,

Optional (Some / Option setters).

pub fn region( self, value: String, ) -> BlobStorageIntegrationResponseBuilder<SetRegion<S>>
where S::Region: IsUnset,

Required.

pub fn access_key_id( self, value: Option<String>, ) -> BlobStorageIntegrationResponseBuilder<SetAccessKeyId<S>>
where S::AccessKeyId: IsUnset,

Optional (Some / Option setters).

pub fn maybe_access_key_id( self, value: Option<Option<String>>, ) -> BlobStorageIntegrationResponseBuilder<SetAccessKeyId<S>>
where S::AccessKeyId: IsUnset,

Optional (Some / Option setters).

pub fn prefix( self, value: String, ) -> BlobStorageIntegrationResponseBuilder<SetPrefix<S>>
where S::Prefix: IsUnset,

Required.

pub fn export_frequency( self, value: BlobStorageExportFrequency, ) -> BlobStorageIntegrationResponseBuilder<SetExportFrequency<S>>
where S::ExportFrequency: IsUnset,

Required.

pub fn enabled( self, value: bool, ) -> BlobStorageIntegrationResponseBuilder<SetEnabled<S>>
where S::Enabled: IsUnset,

Required.

pub fn force_path_style( self, value: bool, ) -> BlobStorageIntegrationResponseBuilder<SetForcePathStyle<S>>
where S::ForcePathStyle: IsUnset,

Required.

pub fn file_type( self, value: BlobStorageIntegrationFileType, ) -> BlobStorageIntegrationResponseBuilder<SetFileType<S>>
where S::FileType: IsUnset,

Required.

pub fn export_mode( self, value: BlobStorageExportMode, ) -> BlobStorageIntegrationResponseBuilder<SetExportMode<S>>
where S::ExportMode: IsUnset,

Required.

pub fn export_start_date( self, value: Option<DateTime<FixedOffset>>, ) -> BlobStorageIntegrationResponseBuilder<SetExportStartDate<S>>
where S::ExportStartDate: IsUnset,

Optional (Some / Option setters).

pub fn maybe_export_start_date( self, value: Option<Option<DateTime<FixedOffset>>>, ) -> BlobStorageIntegrationResponseBuilder<SetExportStartDate<S>>
where S::ExportStartDate: IsUnset,

Optional (Some / Option setters).

pub fn compressed( self, value: bool, ) -> BlobStorageIntegrationResponseBuilder<SetCompressed<S>>
where S::Compressed: IsUnset,

Required.

pub fn export_source( self, value: BlobStorageExportSource, ) -> BlobStorageIntegrationResponseBuilder<SetExportSource<S>>
where S::ExportSource: IsUnset,

Required.

pub fn export_field_groups( self, value: Option<Vec<BlobStorageExportFieldGroup>>, ) -> BlobStorageIntegrationResponseBuilder<SetExportFieldGroups<S>>
where S::ExportFieldGroups: IsUnset,

Optional (Some / Option setters). Field groups included in each exported row for OBSERVATIONS_V2 / LEGACY_TRACES_AND_ENRICHED_OBSERVATIONS sources. Always null when exportSource is LEGACY_TRACES_OBSERVATIONS (the field does not apply to that source; any legacy DB value is hidden from the public surface).

pub fn maybe_export_field_groups( self, value: Option<Option<Vec<BlobStorageExportFieldGroup>>>, ) -> BlobStorageIntegrationResponseBuilder<SetExportFieldGroups<S>>
where S::ExportFieldGroups: IsUnset,

Optional (Some / Option setters). Field groups included in each exported row for OBSERVATIONS_V2 / LEGACY_TRACES_AND_ENRICHED_OBSERVATIONS sources. Always null when exportSource is LEGACY_TRACES_OBSERVATIONS (the field does not apply to that source; any legacy DB value is hidden from the public surface).

pub fn next_sync_at( self, value: Option<DateTime<FixedOffset>>, ) -> BlobStorageIntegrationResponseBuilder<SetNextSyncAt<S>>
where S::NextSyncAt: IsUnset,

Optional (Some / Option setters).

pub fn maybe_next_sync_at( self, value: Option<Option<DateTime<FixedOffset>>>, ) -> BlobStorageIntegrationResponseBuilder<SetNextSyncAt<S>>
where S::NextSyncAt: IsUnset,

Optional (Some / Option setters).

pub fn last_sync_at( self, value: Option<DateTime<FixedOffset>>, ) -> BlobStorageIntegrationResponseBuilder<SetLastSyncAt<S>>
where S::LastSyncAt: IsUnset,

Optional (Some / Option setters).

pub fn maybe_last_sync_at( self, value: Option<Option<DateTime<FixedOffset>>>, ) -> BlobStorageIntegrationResponseBuilder<SetLastSyncAt<S>>
where S::LastSyncAt: IsUnset,

Optional (Some / Option setters).

pub fn last_error( self, value: Option<String>, ) -> BlobStorageIntegrationResponseBuilder<SetLastError<S>>
where S::LastError: IsUnset,

Optional (Some / Option setters).

pub fn maybe_last_error( self, value: Option<Option<String>>, ) -> BlobStorageIntegrationResponseBuilder<SetLastError<S>>
where S::LastError: IsUnset,

Optional (Some / Option setters).

pub fn last_error_at( self, value: Option<DateTime<FixedOffset>>, ) -> BlobStorageIntegrationResponseBuilder<SetLastErrorAt<S>>
where S::LastErrorAt: IsUnset,

Optional (Some / Option setters).

pub fn maybe_last_error_at( self, value: Option<Option<DateTime<FixedOffset>>>, ) -> BlobStorageIntegrationResponseBuilder<SetLastErrorAt<S>>
where S::LastErrorAt: IsUnset,

Optional (Some / Option setters).

pub fn created_at( self, value: DateTime<FixedOffset>, ) -> BlobStorageIntegrationResponseBuilder<SetCreatedAt<S>>
where S::CreatedAt: IsUnset,

Required.

pub fn updated_at( self, value: DateTime<FixedOffset>, ) -> BlobStorageIntegrationResponseBuilder<SetUpdatedAt<S>>
where S::UpdatedAt: IsUnset,

Required.