pub enum BlobStorageSyncStatus {
Idle,
Queued,
UpToDate,
Disabled,
Error,
}Expand description
BlobStorageSyncStatus : Sync status of the blob storage integration: - disabled — integration is not enabled - error — last export failed (see lastError for details) - idle — enabled but has never exported yet - queued — next export is overdue (nextSyncAt is in the past) and waiting to be picked up by the worker - up_to_date — all available data has been exported; next export is scheduled for the future ETL usage: poll this endpoint and check for up_to_date status. Compare lastSyncAt against your ETL bookmark to determine if new data is available. Note that exports run with a 20-minute lag buffer, so lastSyncAt will always be at least 20 minutes behind real-time.
Sync status of the blob storage integration: - disabled — integration is not enabled - error — last export failed (see lastError for details) - idle — enabled but has never exported yet - queued — next export is overdue (nextSyncAt is in the past) and waiting to be picked up by the worker - up_to_date — all available data has been exported; next export is scheduled for the future ETL usage: poll this endpoint and check for up_to_date status. Compare lastSyncAt against your ETL bookmark to determine if new data is available. Note that exports run with a 20-minute lag buffer, so lastSyncAt will always be at least 20 minutes behind real-time.
Variants