pub struct BooleanScore {Show 18 fields
pub id: String,
pub trace_id: Option<Option<String>>,
pub session_id: Option<Option<String>>,
pub observation_id: Option<Option<String>>,
pub dataset_run_id: Option<Option<String>>,
pub name: String,
pub source: ScoreSource,
pub timestamp: DateTime<FixedOffset>,
pub created_at: DateTime<FixedOffset>,
pub updated_at: DateTime<FixedOffset>,
pub author_user_id: Option<Option<String>>,
pub comment: Option<Option<String>>,
pub metadata: Option<Value>,
pub config_id: Option<Option<String>>,
pub queue_id: Option<Option<String>>,
pub environment: String,
pub value: f64,
pub string_value: String,
}Fields
id: Stringtrace_id: Option<Option<String>>The trace ID associated with the score
session_id: Option<Option<String>>The session ID associated with the score
observation_id: Option<Option<String>>The observation ID associated with the score
dataset_run_id: Option<Option<String>>The dataset run ID associated with the score
name: Stringsource: ScoreSourcetimestamp: DateTime<FixedOffset>created_at: DateTime<FixedOffset>updated_at: DateTime<FixedOffset>The user ID of the author
comment: Option<Option<String>>Comment on the score
metadata: Option<Value>Metadata associated with the score
config_id: Option<Option<String>>Reference a score config on a score. When set, config and score name must be equal and value must comply to optionally defined numerical range
queue_id: Option<Option<String>>The annotation queue referenced by the score. Indicates if score was initially created while processing annotation queue.
environment: StringThe environment from which this score originated. Can be any lowercase alphanumeric string with hyphens and underscores that does not start with ‘langfuse’.
value: f64The numeric value of the score. Equals 1 for "True" and 0 for "False"
string_value: StringThe string representation of the score value. Is inferred from the numeric value and equals "True" or "False"
Implementations
Sourceimpl BooleanScore
impl BooleanScore
Sourcepub fn builder() -> BooleanScoreBuilder
pub fn builder() -> BooleanScoreBuilder
Create an instance of BooleanScore using the builder syntax
Sourceimpl BooleanScore
impl BooleanScore
pub fn new( id: String, name: String, source: ScoreSource, timestamp: DateTime<FixedOffset>, created_at: DateTime<FixedOffset>, updated_at: DateTime<FixedOffset>, metadata: Option<Value>, environment: String, value: f64, string_value: String, ) -> BooleanScore