pub struct CreateBlobStorageIntegrationRequestBuilder<S: State = Empty> { /* private fields */ }Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> CreateBlobStorageIntegrationRequestBuilder<S>
impl<S: State> CreateBlobStorageIntegrationRequestBuilder<S>
Sourcepub fn build(self) -> CreateBlobStorageIntegrationRequestwhere
S: IsComplete,
pub fn build(self) -> CreateBlobStorageIntegrationRequestwhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn project_id(
self,
value: String,
) -> CreateBlobStorageIntegrationRequestBuilder<SetProjectId<S>>where
S::ProjectId: IsUnset,
pub fn project_id(
self,
value: String,
) -> CreateBlobStorageIntegrationRequestBuilder<SetProjectId<S>>where
S::ProjectId: IsUnset,
Required.
ID of the project in which to configure the blob storage integration
Sourcepub fn type(
self,
value: BlobStorageIntegrationType,
) -> CreateBlobStorageIntegrationRequestBuilder<SetType<S>>where
S::Type: IsUnset,
pub fn type(
self,
value: BlobStorageIntegrationType,
) -> CreateBlobStorageIntegrationRequestBuilder<SetType<S>>where
S::Type: IsUnset,
Required.
Sourcepub fn bucket_name(
self,
value: String,
) -> CreateBlobStorageIntegrationRequestBuilder<SetBucketName<S>>where
S::BucketName: IsUnset,
pub fn bucket_name(
self,
value: String,
) -> CreateBlobStorageIntegrationRequestBuilder<SetBucketName<S>>where
S::BucketName: IsUnset,
Required.
Name of the storage bucket. For AZURE_BLOB_STORAGE, must be a valid Azure container name (3-63 chars, lowercase letters, numbers, and hyphens only, must start and end with a letter or number, no consecutive hyphens).
Sourcepub fn endpoint(
self,
value: Option<String>,
) -> CreateBlobStorageIntegrationRequestBuilder<SetEndpoint<S>>where
S::Endpoint: IsUnset,
pub fn endpoint(
self,
value: Option<String>,
) -> CreateBlobStorageIntegrationRequestBuilder<SetEndpoint<S>>where
S::Endpoint: IsUnset,
Sourcepub fn maybe_endpoint(
self,
value: Option<Option<String>>,
) -> CreateBlobStorageIntegrationRequestBuilder<SetEndpoint<S>>where
S::Endpoint: IsUnset,
pub fn maybe_endpoint(
self,
value: Option<Option<String>>,
) -> CreateBlobStorageIntegrationRequestBuilder<SetEndpoint<S>>where
S::Endpoint: IsUnset,
Sourcepub fn region(
self,
value: String,
) -> CreateBlobStorageIntegrationRequestBuilder<SetRegion<S>>where
S::Region: IsUnset,
pub fn region(
self,
value: String,
) -> CreateBlobStorageIntegrationRequestBuilder<SetRegion<S>>where
S::Region: IsUnset,
Required.
Storage region
Sourcepub fn access_key_id(
self,
value: Option<String>,
) -> CreateBlobStorageIntegrationRequestBuilder<SetAccessKeyId<S>>where
S::AccessKeyId: IsUnset,
pub fn access_key_id(
self,
value: Option<String>,
) -> CreateBlobStorageIntegrationRequestBuilder<SetAccessKeyId<S>>where
S::AccessKeyId: IsUnset,
Sourcepub fn maybe_access_key_id(
self,
value: Option<Option<String>>,
) -> CreateBlobStorageIntegrationRequestBuilder<SetAccessKeyId<S>>where
S::AccessKeyId: IsUnset,
pub fn maybe_access_key_id(
self,
value: Option<Option<String>>,
) -> CreateBlobStorageIntegrationRequestBuilder<SetAccessKeyId<S>>where
S::AccessKeyId: IsUnset,
Sourcepub fn secret_access_key(
self,
value: Option<String>,
) -> CreateBlobStorageIntegrationRequestBuilder<SetSecretAccessKey<S>>where
S::SecretAccessKey: IsUnset,
pub fn secret_access_key(
self,
value: Option<String>,
) -> CreateBlobStorageIntegrationRequestBuilder<SetSecretAccessKey<S>>where
S::SecretAccessKey: IsUnset,
Sourcepub fn maybe_secret_access_key(
self,
value: Option<Option<String>>,
) -> CreateBlobStorageIntegrationRequestBuilder<SetSecretAccessKey<S>>where
S::SecretAccessKey: IsUnset,
pub fn maybe_secret_access_key(
self,
value: Option<Option<String>>,
) -> CreateBlobStorageIntegrationRequestBuilder<SetSecretAccessKey<S>>where
S::SecretAccessKey: IsUnset,
Sourcepub fn prefix(
self,
value: Option<String>,
) -> CreateBlobStorageIntegrationRequestBuilder<SetPrefix<S>>where
S::Prefix: IsUnset,
pub fn prefix(
self,
value: Option<String>,
) -> CreateBlobStorageIntegrationRequestBuilder<SetPrefix<S>>where
S::Prefix: IsUnset,
Sourcepub fn maybe_prefix(
self,
value: Option<Option<String>>,
) -> CreateBlobStorageIntegrationRequestBuilder<SetPrefix<S>>where
S::Prefix: IsUnset,
pub fn maybe_prefix(
self,
value: Option<Option<String>>,
) -> CreateBlobStorageIntegrationRequestBuilder<SetPrefix<S>>where
S::Prefix: IsUnset,
Sourcepub fn export_frequency(
self,
value: BlobStorageExportFrequency,
) -> CreateBlobStorageIntegrationRequestBuilder<SetExportFrequency<S>>where
S::ExportFrequency: IsUnset,
pub fn export_frequency(
self,
value: BlobStorageExportFrequency,
) -> CreateBlobStorageIntegrationRequestBuilder<SetExportFrequency<S>>where
S::ExportFrequency: IsUnset,
Required.
Sourcepub fn enabled(
self,
value: bool,
) -> CreateBlobStorageIntegrationRequestBuilder<SetEnabled<S>>where
S::Enabled: IsUnset,
pub fn enabled(
self,
value: bool,
) -> CreateBlobStorageIntegrationRequestBuilder<SetEnabled<S>>where
S::Enabled: IsUnset,
Required.
Whether the integration is active
Sourcepub fn force_path_style(
self,
value: bool,
) -> CreateBlobStorageIntegrationRequestBuilder<SetForcePathStyle<S>>where
S::ForcePathStyle: IsUnset,
pub fn force_path_style(
self,
value: bool,
) -> CreateBlobStorageIntegrationRequestBuilder<SetForcePathStyle<S>>where
S::ForcePathStyle: IsUnset,
Required.
Use path-style URLs for S3 requests
Sourcepub fn file_type(
self,
value: BlobStorageIntegrationFileType,
) -> CreateBlobStorageIntegrationRequestBuilder<SetFileType<S>>where
S::FileType: IsUnset,
pub fn file_type(
self,
value: BlobStorageIntegrationFileType,
) -> CreateBlobStorageIntegrationRequestBuilder<SetFileType<S>>where
S::FileType: IsUnset,
Required.
Sourcepub fn export_mode(
self,
value: BlobStorageExportMode,
) -> CreateBlobStorageIntegrationRequestBuilder<SetExportMode<S>>where
S::ExportMode: IsUnset,
pub fn export_mode(
self,
value: BlobStorageExportMode,
) -> CreateBlobStorageIntegrationRequestBuilder<SetExportMode<S>>where
S::ExportMode: IsUnset,
Required.
Sourcepub fn export_start_date(
self,
value: Option<DateTime<FixedOffset>>,
) -> CreateBlobStorageIntegrationRequestBuilder<SetExportStartDate<S>>where
S::ExportStartDate: IsUnset,
pub fn export_start_date(
self,
value: Option<DateTime<FixedOffset>>,
) -> CreateBlobStorageIntegrationRequestBuilder<SetExportStartDate<S>>where
S::ExportStartDate: IsUnset,
Sourcepub fn maybe_export_start_date(
self,
value: Option<Option<DateTime<FixedOffset>>>,
) -> CreateBlobStorageIntegrationRequestBuilder<SetExportStartDate<S>>where
S::ExportStartDate: IsUnset,
pub fn maybe_export_start_date(
self,
value: Option<Option<DateTime<FixedOffset>>>,
) -> CreateBlobStorageIntegrationRequestBuilder<SetExportStartDate<S>>where
S::ExportStartDate: IsUnset,
Sourcepub fn compressed(
self,
value: Option<bool>,
) -> CreateBlobStorageIntegrationRequestBuilder<SetCompressed<S>>where
S::Compressed: IsUnset,
pub fn compressed(
self,
value: Option<bool>,
) -> CreateBlobStorageIntegrationRequestBuilder<SetCompressed<S>>where
S::Compressed: IsUnset,
Sourcepub fn maybe_compressed(
self,
value: Option<Option<bool>>,
) -> CreateBlobStorageIntegrationRequestBuilder<SetCompressed<S>>where
S::Compressed: IsUnset,
pub fn maybe_compressed(
self,
value: Option<Option<bool>>,
) -> CreateBlobStorageIntegrationRequestBuilder<SetCompressed<S>>where
S::Compressed: IsUnset,
Sourcepub fn export_source(
self,
value: BlobStorageExportSource,
) -> CreateBlobStorageIntegrationRequestBuilder<SetExportSource<S>>where
S::ExportSource: IsUnset,
pub fn export_source(
self,
value: BlobStorageExportSource,
) -> CreateBlobStorageIntegrationRequestBuilder<SetExportSource<S>>where
S::ExportSource: IsUnset,
Sourcepub fn maybe_export_source(
self,
value: Option<BlobStorageExportSource>,
) -> CreateBlobStorageIntegrationRequestBuilder<SetExportSource<S>>where
S::ExportSource: IsUnset,
pub fn maybe_export_source(
self,
value: Option<BlobStorageExportSource>,
) -> CreateBlobStorageIntegrationRequestBuilder<SetExportSource<S>>where
S::ExportSource: IsUnset,
Sourcepub fn export_field_groups(
self,
value: Option<Vec<BlobStorageExportFieldGroup>>,
) -> CreateBlobStorageIntegrationRequestBuilder<SetExportFieldGroups<S>>where
S::ExportFieldGroups: IsUnset,
pub fn export_field_groups(
self,
value: Option<Vec<BlobStorageExportFieldGroup>>,
) -> CreateBlobStorageIntegrationRequestBuilder<SetExportFieldGroups<S>>where
S::ExportFieldGroups: IsUnset,
Optional (Some / Option setters).
Field groups to include in each exported row. For exportSource OBSERVATIONS_V2 or LEGACY_TRACES_AND_ENRICHED_OBSERVATIONS: must include core if provided. When omitted on create, the column default (all groups) applies. When omitted on update, the existing value is preserved. For exportSource LEGACY_TRACES_OBSERVATIONS: this field must be omitted or null. Sending an array (including an empty array) returns 400, because that source uses a fixed column set and does not honor field groups. exportFieldGroups requires exportSource to be provided in the same request.
Sourcepub fn maybe_export_field_groups(
self,
value: Option<Option<Vec<BlobStorageExportFieldGroup>>>,
) -> CreateBlobStorageIntegrationRequestBuilder<SetExportFieldGroups<S>>where
S::ExportFieldGroups: IsUnset,
pub fn maybe_export_field_groups(
self,
value: Option<Option<Vec<BlobStorageExportFieldGroup>>>,
) -> CreateBlobStorageIntegrationRequestBuilder<SetExportFieldGroups<S>>where
S::ExportFieldGroups: IsUnset,
Optional (Some / Option setters).
Field groups to include in each exported row. For exportSource OBSERVATIONS_V2 or LEGACY_TRACES_AND_ENRICHED_OBSERVATIONS: must include core if provided. When omitted on create, the column default (all groups) applies. When omitted on update, the existing value is preserved. For exportSource LEGACY_TRACES_OBSERVATIONS: this field must be omitted or null. Sending an array (including an empty array) returns 400, because that source uses a fixed column set and does not honor field groups. exportFieldGroups requires exportSource to be provided in the same request.