pub struct CreateDatasetRunItemRequest {
pub run_name: String,
pub run_description: Option<Option<String>>,
pub metadata: Option<Option<Value>>,
pub dataset_item_id: String,
pub observation_id: Option<Option<String>>,
pub trace_id: Option<Option<String>>,
pub dataset_version: Option<Option<String>>,
pub created_at: Option<Option<String>>,
}Fields
run_name: Stringrun_description: Option<Option<String>>Description of the run. If run exists, description will be updated.
metadata: Option<Option<Value>>Metadata of the dataset run, updates run if run already exists
dataset_item_id: Stringobservation_id: Option<Option<String>>trace_id: Option<Option<String>>traceId should always be provided. For compatibility with older SDK versions it can also be inferred from the provided observationId.
dataset_version: Option<Option<String>>ISO 8601 timestamp (RFC 3339, Section 5.6) in UTC (e.g., "2026-01-21T14:35:42Z"). Specifies the dataset version to use for this experiment run. If provided, the experiment will use dataset items as they existed at or before this timestamp. If not provided, uses the latest version of dataset items.
created_at: Option<Option<String>>Optional timestamp to set the createdAt field of the dataset run item. If not provided or null, defaults to current timestamp.
Implementations
Sourceimpl CreateDatasetRunItemRequest
impl CreateDatasetRunItemRequest
Sourcepub fn builder() -> CreateDatasetRunItemRequestBuilder
pub fn builder() -> CreateDatasetRunItemRequestBuilder
Create an instance of CreateDatasetRunItemRequest using the builder syntax
Sourceimpl CreateDatasetRunItemRequest
impl CreateDatasetRunItemRequest
pub fn new( run_name: String, dataset_item_id: String, ) -> CreateDatasetRunItemRequest