CreateDatasetRunItemRequestBuilder

Struct CreateDatasetRunItemRequestBuilder 

pub struct CreateDatasetRunItemRequestBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> CreateDatasetRunItemRequestBuilder<S>

pub fn build(self) -> CreateDatasetRunItemRequest
where S: IsComplete,

Finish building and return the requested object

pub fn run_name( self, value: String, ) -> CreateDatasetRunItemRequestBuilder<SetRunName<S>>
where S::RunName: IsUnset,

Required.

pub fn run_description( self, value: Option<String>, ) -> CreateDatasetRunItemRequestBuilder<SetRunDescription<S>>
where S::RunDescription: IsUnset,

Optional (Some / Option setters). Description of the run. If run exists, description will be updated.

pub fn maybe_run_description( self, value: Option<Option<String>>, ) -> CreateDatasetRunItemRequestBuilder<SetRunDescription<S>>
where S::RunDescription: IsUnset,

Optional (Some / Option setters). Description of the run. If run exists, description will be updated.

pub fn metadata( self, value: Option<Value>, ) -> CreateDatasetRunItemRequestBuilder<SetMetadata<S>>
where S::Metadata: IsUnset,

Optional (Some / Option setters). Metadata of the dataset run, updates run if run already exists

pub fn maybe_metadata( self, value: Option<Option<Value>>, ) -> CreateDatasetRunItemRequestBuilder<SetMetadata<S>>
where S::Metadata: IsUnset,

Optional (Some / Option setters). Metadata of the dataset run, updates run if run already exists

pub fn dataset_item_id( self, value: String, ) -> CreateDatasetRunItemRequestBuilder<SetDatasetItemId<S>>
where S::DatasetItemId: IsUnset,

Required.

pub fn observation_id( self, value: Option<String>, ) -> CreateDatasetRunItemRequestBuilder<SetObservationId<S>>
where S::ObservationId: IsUnset,

Optional (Some / Option setters).

pub fn maybe_observation_id( self, value: Option<Option<String>>, ) -> CreateDatasetRunItemRequestBuilder<SetObservationId<S>>
where S::ObservationId: IsUnset,

Optional (Some / Option setters).

pub fn trace_id( self, value: Option<String>, ) -> CreateDatasetRunItemRequestBuilder<SetTraceId<S>>
where S::TraceId: IsUnset,

Optional (Some / Option setters). traceId should always be provided. For compatibility with older SDK versions it can also be inferred from the provided observationId.

pub fn maybe_trace_id( self, value: Option<Option<String>>, ) -> CreateDatasetRunItemRequestBuilder<SetTraceId<S>>
where S::TraceId: IsUnset,

Optional (Some / Option setters). traceId should always be provided. For compatibility with older SDK versions it can also be inferred from the provided observationId.

pub fn dataset_version( self, value: Option<String>, ) -> CreateDatasetRunItemRequestBuilder<SetDatasetVersion<S>>
where S::DatasetVersion: IsUnset,

Optional (Some / Option setters). ISO 8601 timestamp (RFC 3339, Section 5.6) in UTC (e.g., "2026-01-21T14:35:42Z"). Specifies the dataset version to use for this experiment run. If provided, the experiment will use dataset items as they existed at or before this timestamp. If not provided, uses the latest version of dataset items.

pub fn maybe_dataset_version( self, value: Option<Option<String>>, ) -> CreateDatasetRunItemRequestBuilder<SetDatasetVersion<S>>
where S::DatasetVersion: IsUnset,

Optional (Some / Option setters). ISO 8601 timestamp (RFC 3339, Section 5.6) in UTC (e.g., "2026-01-21T14:35:42Z"). Specifies the dataset version to use for this experiment run. If provided, the experiment will use dataset items as they existed at or before this timestamp. If not provided, uses the latest version of dataset items.