LlmConnectionBuilder

Struct LlmConnectionBuilder 

pub struct LlmConnectionBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> LlmConnectionBuilder<S>

pub fn build(self) -> LlmConnection
where S: IsComplete,

Finish building and return the requested object

pub fn id(self, value: String) -> LlmConnectionBuilder<SetId<S>>
where S::Id: IsUnset,

Required.

pub fn provider(self, value: String) -> LlmConnectionBuilder<SetProvider<S>>
where S::Provider: IsUnset,

Required.

Provider name (e.g., ‘openai’, ‘my-gateway’). Must be unique in project, used for upserting.

pub fn adapter(self, value: String) -> LlmConnectionBuilder<SetAdapter<S>>
where S::Adapter: IsUnset,

Required.

The adapter used to interface with the LLM

pub fn display_secret_key( self, value: String, ) -> LlmConnectionBuilder<SetDisplaySecretKey<S>>
where S::DisplaySecretKey: IsUnset,

Required.

Masked version of the secret key for display purposes

pub fn base_url( self, value: Option<String>, ) -> LlmConnectionBuilder<SetBaseUrl<S>>
where S::BaseUrl: IsUnset,

Optional (Some / Option setters). Custom base URL for the LLM API

pub fn maybe_base_url( self, value: Option<Option<String>>, ) -> LlmConnectionBuilder<SetBaseUrl<S>>
where S::BaseUrl: IsUnset,

Optional (Some / Option setters). Custom base URL for the LLM API

pub fn custom_models( self, value: Vec<String>, ) -> LlmConnectionBuilder<SetCustomModels<S>>
where S::CustomModels: IsUnset,

Required.

List of custom model names available for this connection

pub fn with_default_models( self, value: bool, ) -> LlmConnectionBuilder<SetWithDefaultModels<S>>
where S::WithDefaultModels: IsUnset,

Required.

Whether to include default models for this adapter

pub fn extra_header_keys( self, value: Vec<String>, ) -> LlmConnectionBuilder<SetExtraHeaderKeys<S>>
where S::ExtraHeaderKeys: IsUnset,

Required.

Keys of extra headers sent with requests (values excluded for security)

pub fn config( self, value: Option<HashMap<String, Value>>, ) -> LlmConnectionBuilder<SetConfig<S>>
where S::Config: IsUnset,

Optional (Some / Option setters). Adapter-specific configuration. Required for Bedrock ({\"region\":\"us-east-1\"}), optional for VertexAI ({\"location\":\"us-central1\"}), not used by other adapters.

pub fn maybe_config( self, value: Option<Option<HashMap<String, Value>>>, ) -> LlmConnectionBuilder<SetConfig<S>>
where S::Config: IsUnset,

Optional (Some / Option setters). Adapter-specific configuration. Required for Bedrock ({\"region\":\"us-east-1\"}), optional for VertexAI ({\"location\":\"us-central1\"}), not used by other adapters.

pub fn created_at( self, value: DateTime<FixedOffset>, ) -> LlmConnectionBuilder<SetCreatedAt<S>>
where S::CreatedAt: IsUnset,

Required.

pub fn updated_at( self, value: DateTime<FixedOffset>, ) -> LlmConnectionBuilder<SetUpdatedAt<S>>
where S::UpdatedAt: IsUnset,

Required.