pub struct TextScore {Show 17 fields
pub id: String,
pub trace_id: Option<Option<String>>,
pub session_id: Option<Option<String>>,
pub observation_id: Option<Option<String>>,
pub dataset_run_id: Option<Option<String>>,
pub name: String,
pub source: ScoreSource,
pub timestamp: DateTime<FixedOffset>,
pub created_at: DateTime<FixedOffset>,
pub updated_at: DateTime<FixedOffset>,
pub author_user_id: Option<Option<String>>,
pub comment: Option<Option<String>>,
pub metadata: Option<Value>,
pub config_id: Option<Option<String>>,
pub queue_id: Option<Option<String>>,
pub environment: String,
pub string_value: String,
}Fields
id: Stringtrace_id: Option<Option<String>>The trace ID associated with the score
session_id: Option<Option<String>>The session ID associated with the score
observation_id: Option<Option<String>>The observation ID associated with the score
dataset_run_id: Option<Option<String>>The dataset run ID associated with the score
name: Stringsource: ScoreSourcetimestamp: DateTime<FixedOffset>created_at: DateTime<FixedOffset>updated_at: DateTime<FixedOffset>The user ID of the author
comment: Option<Option<String>>Comment on the score
metadata: Option<Value>Metadata associated with the score
config_id: Option<Option<String>>Reference a score config on a score. When set, config and score name must be equal and value must comply to optionally defined numerical range
queue_id: Option<Option<String>>The annotation queue referenced by the score. Indicates if score was initially created while processing annotation queue.
environment: StringThe environment from which this score originated. Can be any lowercase alphanumeric string with hyphens and underscores that does not start with ‘langfuse’.
string_value: StringThe text content of the score (1-500 characters)
Implementations
Sourceimpl TextScore
impl TextScore
Sourcepub fn builder() -> TextScoreBuilder
pub fn builder() -> TextScoreBuilder
Create an instance of TextScore using the builder syntax