pub struct TextScoreV1 {Show 15 fields
pub id: String,
pub trace_id: String,
pub name: String,
pub source: ScoreSource,
pub observation_id: Option<Option<String>>,
pub timestamp: DateTime<FixedOffset>,
pub created_at: DateTime<FixedOffset>,
pub updated_at: DateTime<FixedOffset>,
pub author_user_id: Option<Option<String>>,
pub comment: Option<Option<String>>,
pub metadata: Option<Value>,
pub config_id: Option<Option<String>>,
pub queue_id: Option<Option<String>>,
pub environment: String,
pub string_value: String,
}Fields
id: Stringtrace_id: Stringname: Stringsource: ScoreSourceobservation_id: Option<Option<String>>The observation ID associated with the score
timestamp: DateTime<FixedOffset>created_at: DateTime<FixedOffset>updated_at: DateTime<FixedOffset>The user ID of the author
comment: Option<Option<String>>Comment on the score
metadata: Option<Value>Metadata associated with the score
config_id: Option<Option<String>>Reference a score config on a score. When set, config and score name must be equal and value must comply to optionally defined numerical range
queue_id: Option<Option<String>>The annotation queue referenced by the score. Indicates if score was initially created while processing annotation queue.
environment: StringThe environment from which this score originated. Can be any lowercase alphanumeric string with hyphens and underscores that does not start with ‘langfuse’.
string_value: StringThe text content of the score (1-500 characters)
Implementations
Sourceimpl TextScoreV1
impl TextScoreV1
Sourcepub fn builder() -> TextScoreV1Builder
pub fn builder() -> TextScoreV1Builder
Create an instance of TextScoreV1 using the builder syntax
Sourceimpl TextScoreV1
impl TextScoreV1
pub fn new( id: String, trace_id: String, name: String, source: ScoreSource, timestamp: DateTime<FixedOffset>, created_at: DateTime<FixedOffset>, updated_at: DateTime<FixedOffset>, metadata: Option<Value>, environment: String, string_value: String, ) -> TextScoreV1