UnstableCreateEvaluatorRequest

Struct UnstableCreateEvaluatorRequest 

pub struct UnstableCreateEvaluatorRequest {
    pub name: String,
    pub prompt: String,
    pub output_definition: Box<UnstableEvaluatorOutputDefinition>,
    pub model_config: Option<Box<UnstableEvaluatorModelConfig>>,
}
UnstableCreateEvaluatorRequest : Request body for creating an evaluator. If the same name already exists in your project, Langfuse creates the next version and returns it. Existing evaluation rules in the same project are then moved to that new latest version automatically.

Fields

name: String

Evaluator name within the authenticated project.

prompt: String

Prompt template used by the evaluator.

output_definition: Box<UnstableEvaluatorOutputDefinition>model_config: Option<Box<UnstableEvaluatorModelConfig>>

Implementations

Source

impl UnstableCreateEvaluatorRequest

pub fn builder() -> UnstableCreateEvaluatorRequestBuilder

Create an instance of UnstableCreateEvaluatorRequest using the builder syntax

Source

impl UnstableCreateEvaluatorRequest

pub fn new( name: String, prompt: String, output_definition: UnstableEvaluatorOutputDefinition, ) -> UnstableCreateEvaluatorRequest

Request body for creating an evaluator. If the same name already exists in your project, Langfuse creates the next version and returns it. Existing evaluation rules in the same project are then moved to that new latest version automatically.