pub enum UnstablePublicApiErrorCode {
Show 18 variants
AuthenticationFailed,
AccessDenied,
InvalidRequest,
InvalidQuery,
InvalidBody,
InvalidFilterValue,
InvalidJsonPath,
InvalidVariableMapping,
MissingVariableMapping,
DuplicateVariableMapping,
ResourceNotFound,
NameConflict,
EvaluatorPreflightFailed,
Conflict,
UnprocessableContent,
RateLimited,
MethodNotAllowed,
InternalError,
}Expand description
UnstablePublicApiErrorCode : Machine-readable error code returned by the unstable evaluators API. SDKs, CLIs, and agents should branch on code rather than parsing the human-readable message. The HTTP status still indicates the broad error class, while code gives the specific failure reason.
Machine-readable error code returned by the unstable evaluators API. SDKs, CLIs, and agents should branch on code rather than parsing the human-readable message. The HTTP status still indicates the broad error class, while code gives the specific failure reason.
Variants
AuthenticationFailed
AccessDenied
InvalidRequest
InvalidQuery
InvalidBody
InvalidFilterValue
InvalidJsonPath
InvalidVariableMapping
MissingVariableMapping
DuplicateVariableMapping
ResourceNotFound
NameConflict
EvaluatorPreflightFailed
Conflict
UnprocessableContent
RateLimited
MethodNotAllowed
InternalError