pub struct UnstablePublicApiValidationIssue {
pub code: String,
pub message: String,
pub path: Vec<Value>,
}Expand description
UnstablePublicApiValidationIssue : One validation issue returned for malformed request bodies or query parameters. This mirrors the most important parts of a Zod issue: a machine-readable code, a human-readable message, and a structured path.
Fields
code: StringMachine-readable validation issue code emitted by the server validator.
message: StringHuman-readable explanation of the validation failure.
path: Vec<Value>Path to the invalid field, for example [\"mapping\", 0, \"jsonPath\"].
Implementations
Sourceimpl UnstablePublicApiValidationIssue
impl UnstablePublicApiValidationIssue
Sourcepub fn builder() -> UnstablePublicApiValidationIssueBuilder
pub fn builder() -> UnstablePublicApiValidationIssueBuilder
Create an instance of UnstablePublicApiValidationIssue using the builder syntax
Sourceimpl UnstablePublicApiValidationIssue
impl UnstablePublicApiValidationIssue
Sourcepub fn new(
code: String,
message: String,
path: Vec<Value>,
) -> UnstablePublicApiValidationIssue
pub fn new( code: String, message: String, path: Vec<Value>, ) -> UnstablePublicApiValidationIssue
One validation issue returned for malformed request bodies or query parameters. This mirrors the most important parts of a Zod issue: a machine-readable code, a human-readable message, and a structured path.