Structs
- Models
Create Builder - Use builder syntax to set the inputs and finish with
call(). - Models
Delete Builder - Use builder syntax to set the inputs and finish with
call(). - Models
GetBuilder - Use builder syntax to set the inputs and finish with
call(). - Models
List Builder - Use builder syntax to set the inputs and finish with
call().
Enums
- Models
Create Error - struct for typed errors of method
models_create - Models
Delete Error - struct for typed errors of method
models_delete - Models
GetError - struct for typed errors of method
models_get - Models
List Error - struct for typed errors of method
models_list
Functions
- models_
create - Create a model
- models_
delete - Delete a model. Cannot delete models managed by Langfuse. You can create your own definition with the same modelName to override the definition though.
- models_
get - Get a model
- models_
list - Get all models