Structs
- Scores
GetBy IdBuilder - Use builder syntax to set the inputs and finish with
call(). - Scores
GetMany Builder - Use builder syntax to set the inputs and finish with
call().
Enums
- Scores
GetBy IdError - struct for typed errors of method
scores_get_by_id - Scores
GetMany Error - struct for typed errors of method
scores_get_many
Functions
- scores_
get_ by_ id - Get a score (supports both trace and session scores)
- scores_
get_ many - Get a list of scores (supports both trace and session scores)