pub struct BlobStorageIntegrationResponseBuilder<S: State = Empty> { /* private fields */ }Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> BlobStorageIntegrationResponseBuilder<S>
impl<S: State> BlobStorageIntegrationResponseBuilder<S>
Sourcepub fn build(self) -> BlobStorageIntegrationResponsewhere
S: IsComplete,
pub fn build(self) -> BlobStorageIntegrationResponsewhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn id(
self,
value: String,
) -> BlobStorageIntegrationResponseBuilder<SetId<S>>where
S::Id: IsUnset,
pub fn id(
self,
value: String,
) -> BlobStorageIntegrationResponseBuilder<SetId<S>>where
S::Id: IsUnset,
Required.
Sourcepub fn project_id(
self,
value: String,
) -> BlobStorageIntegrationResponseBuilder<SetProjectId<S>>where
S::ProjectId: IsUnset,
pub fn project_id(
self,
value: String,
) -> BlobStorageIntegrationResponseBuilder<SetProjectId<S>>where
S::ProjectId: IsUnset,
Required.
Sourcepub fn type(
self,
value: BlobStorageIntegrationType,
) -> BlobStorageIntegrationResponseBuilder<SetType<S>>where
S::Type: IsUnset,
pub fn type(
self,
value: BlobStorageIntegrationType,
) -> BlobStorageIntegrationResponseBuilder<SetType<S>>where
S::Type: IsUnset,
Required.
Sourcepub fn bucket_name(
self,
value: String,
) -> BlobStorageIntegrationResponseBuilder<SetBucketName<S>>where
S::BucketName: IsUnset,
pub fn bucket_name(
self,
value: String,
) -> BlobStorageIntegrationResponseBuilder<SetBucketName<S>>where
S::BucketName: IsUnset,
Required.
Sourcepub fn endpoint(
self,
value: Option<String>,
) -> BlobStorageIntegrationResponseBuilder<SetEndpoint<S>>where
S::Endpoint: IsUnset,
pub fn endpoint(
self,
value: Option<String>,
) -> BlobStorageIntegrationResponseBuilder<SetEndpoint<S>>where
S::Endpoint: IsUnset,
Sourcepub fn maybe_endpoint(
self,
value: Option<Option<String>>,
) -> BlobStorageIntegrationResponseBuilder<SetEndpoint<S>>where
S::Endpoint: IsUnset,
pub fn maybe_endpoint(
self,
value: Option<Option<String>>,
) -> BlobStorageIntegrationResponseBuilder<SetEndpoint<S>>where
S::Endpoint: IsUnset,
Sourcepub fn region(
self,
value: String,
) -> BlobStorageIntegrationResponseBuilder<SetRegion<S>>where
S::Region: IsUnset,
pub fn region(
self,
value: String,
) -> BlobStorageIntegrationResponseBuilder<SetRegion<S>>where
S::Region: IsUnset,
Required.
Sourcepub fn access_key_id(
self,
value: Option<String>,
) -> BlobStorageIntegrationResponseBuilder<SetAccessKeyId<S>>where
S::AccessKeyId: IsUnset,
pub fn access_key_id(
self,
value: Option<String>,
) -> BlobStorageIntegrationResponseBuilder<SetAccessKeyId<S>>where
S::AccessKeyId: IsUnset,
Sourcepub fn maybe_access_key_id(
self,
value: Option<Option<String>>,
) -> BlobStorageIntegrationResponseBuilder<SetAccessKeyId<S>>where
S::AccessKeyId: IsUnset,
pub fn maybe_access_key_id(
self,
value: Option<Option<String>>,
) -> BlobStorageIntegrationResponseBuilder<SetAccessKeyId<S>>where
S::AccessKeyId: IsUnset,
Sourcepub fn prefix(
self,
value: String,
) -> BlobStorageIntegrationResponseBuilder<SetPrefix<S>>where
S::Prefix: IsUnset,
pub fn prefix(
self,
value: String,
) -> BlobStorageIntegrationResponseBuilder<SetPrefix<S>>where
S::Prefix: IsUnset,
Required.
Sourcepub fn export_frequency(
self,
value: BlobStorageExportFrequency,
) -> BlobStorageIntegrationResponseBuilder<SetExportFrequency<S>>where
S::ExportFrequency: IsUnset,
pub fn export_frequency(
self,
value: BlobStorageExportFrequency,
) -> BlobStorageIntegrationResponseBuilder<SetExportFrequency<S>>where
S::ExportFrequency: IsUnset,
Required.
Sourcepub fn enabled(
self,
value: bool,
) -> BlobStorageIntegrationResponseBuilder<SetEnabled<S>>where
S::Enabled: IsUnset,
pub fn enabled(
self,
value: bool,
) -> BlobStorageIntegrationResponseBuilder<SetEnabled<S>>where
S::Enabled: IsUnset,
Required.
Sourcepub fn force_path_style(
self,
value: bool,
) -> BlobStorageIntegrationResponseBuilder<SetForcePathStyle<S>>where
S::ForcePathStyle: IsUnset,
pub fn force_path_style(
self,
value: bool,
) -> BlobStorageIntegrationResponseBuilder<SetForcePathStyle<S>>where
S::ForcePathStyle: IsUnset,
Required.
Sourcepub fn file_type(
self,
value: BlobStorageIntegrationFileType,
) -> BlobStorageIntegrationResponseBuilder<SetFileType<S>>where
S::FileType: IsUnset,
pub fn file_type(
self,
value: BlobStorageIntegrationFileType,
) -> BlobStorageIntegrationResponseBuilder<SetFileType<S>>where
S::FileType: IsUnset,
Required.
Sourcepub fn export_mode(
self,
value: BlobStorageExportMode,
) -> BlobStorageIntegrationResponseBuilder<SetExportMode<S>>where
S::ExportMode: IsUnset,
pub fn export_mode(
self,
value: BlobStorageExportMode,
) -> BlobStorageIntegrationResponseBuilder<SetExportMode<S>>where
S::ExportMode: IsUnset,
Required.
Sourcepub fn export_start_date(
self,
value: Option<DateTime<FixedOffset>>,
) -> BlobStorageIntegrationResponseBuilder<SetExportStartDate<S>>where
S::ExportStartDate: IsUnset,
pub fn export_start_date(
self,
value: Option<DateTime<FixedOffset>>,
) -> BlobStorageIntegrationResponseBuilder<SetExportStartDate<S>>where
S::ExportStartDate: IsUnset,
Sourcepub fn maybe_export_start_date(
self,
value: Option<Option<DateTime<FixedOffset>>>,
) -> BlobStorageIntegrationResponseBuilder<SetExportStartDate<S>>where
S::ExportStartDate: IsUnset,
pub fn maybe_export_start_date(
self,
value: Option<Option<DateTime<FixedOffset>>>,
) -> BlobStorageIntegrationResponseBuilder<SetExportStartDate<S>>where
S::ExportStartDate: IsUnset,
Sourcepub fn compressed(
self,
value: bool,
) -> BlobStorageIntegrationResponseBuilder<SetCompressed<S>>where
S::Compressed: IsUnset,
pub fn compressed(
self,
value: bool,
) -> BlobStorageIntegrationResponseBuilder<SetCompressed<S>>where
S::Compressed: IsUnset,
Required.
Sourcepub fn export_source(
self,
value: BlobStorageExportSource,
) -> BlobStorageIntegrationResponseBuilder<SetExportSource<S>>where
S::ExportSource: IsUnset,
pub fn export_source(
self,
value: BlobStorageExportSource,
) -> BlobStorageIntegrationResponseBuilder<SetExportSource<S>>where
S::ExportSource: IsUnset,
Required.
Sourcepub fn export_field_groups(
self,
value: Option<Vec<BlobStorageExportFieldGroup>>,
) -> BlobStorageIntegrationResponseBuilder<SetExportFieldGroups<S>>where
S::ExportFieldGroups: IsUnset,
pub fn export_field_groups(
self,
value: Option<Vec<BlobStorageExportFieldGroup>>,
) -> BlobStorageIntegrationResponseBuilder<SetExportFieldGroups<S>>where
S::ExportFieldGroups: IsUnset,
Optional (Some / Option setters).
Field groups included in each exported row for OBSERVATIONS_V2 / LEGACY_TRACES_AND_ENRICHED_OBSERVATIONS sources. Always null when exportSource is LEGACY_TRACES_OBSERVATIONS (the field does not apply to that source; any legacy DB value is hidden from the public surface).
Sourcepub fn maybe_export_field_groups(
self,
value: Option<Option<Vec<BlobStorageExportFieldGroup>>>,
) -> BlobStorageIntegrationResponseBuilder<SetExportFieldGroups<S>>where
S::ExportFieldGroups: IsUnset,
pub fn maybe_export_field_groups(
self,
value: Option<Option<Vec<BlobStorageExportFieldGroup>>>,
) -> BlobStorageIntegrationResponseBuilder<SetExportFieldGroups<S>>where
S::ExportFieldGroups: IsUnset,
Optional (Some / Option setters).
Field groups included in each exported row for OBSERVATIONS_V2 / LEGACY_TRACES_AND_ENRICHED_OBSERVATIONS sources. Always null when exportSource is LEGACY_TRACES_OBSERVATIONS (the field does not apply to that source; any legacy DB value is hidden from the public surface).
Sourcepub fn next_sync_at(
self,
value: Option<DateTime<FixedOffset>>,
) -> BlobStorageIntegrationResponseBuilder<SetNextSyncAt<S>>where
S::NextSyncAt: IsUnset,
pub fn next_sync_at(
self,
value: Option<DateTime<FixedOffset>>,
) -> BlobStorageIntegrationResponseBuilder<SetNextSyncAt<S>>where
S::NextSyncAt: IsUnset,
Sourcepub fn maybe_next_sync_at(
self,
value: Option<Option<DateTime<FixedOffset>>>,
) -> BlobStorageIntegrationResponseBuilder<SetNextSyncAt<S>>where
S::NextSyncAt: IsUnset,
pub fn maybe_next_sync_at(
self,
value: Option<Option<DateTime<FixedOffset>>>,
) -> BlobStorageIntegrationResponseBuilder<SetNextSyncAt<S>>where
S::NextSyncAt: IsUnset,
Sourcepub fn last_sync_at(
self,
value: Option<DateTime<FixedOffset>>,
) -> BlobStorageIntegrationResponseBuilder<SetLastSyncAt<S>>where
S::LastSyncAt: IsUnset,
pub fn last_sync_at(
self,
value: Option<DateTime<FixedOffset>>,
) -> BlobStorageIntegrationResponseBuilder<SetLastSyncAt<S>>where
S::LastSyncAt: IsUnset,
Sourcepub fn maybe_last_sync_at(
self,
value: Option<Option<DateTime<FixedOffset>>>,
) -> BlobStorageIntegrationResponseBuilder<SetLastSyncAt<S>>where
S::LastSyncAt: IsUnset,
pub fn maybe_last_sync_at(
self,
value: Option<Option<DateTime<FixedOffset>>>,
) -> BlobStorageIntegrationResponseBuilder<SetLastSyncAt<S>>where
S::LastSyncAt: IsUnset,
Sourcepub fn last_error(
self,
value: Option<String>,
) -> BlobStorageIntegrationResponseBuilder<SetLastError<S>>where
S::LastError: IsUnset,
pub fn last_error(
self,
value: Option<String>,
) -> BlobStorageIntegrationResponseBuilder<SetLastError<S>>where
S::LastError: IsUnset,
Sourcepub fn maybe_last_error(
self,
value: Option<Option<String>>,
) -> BlobStorageIntegrationResponseBuilder<SetLastError<S>>where
S::LastError: IsUnset,
pub fn maybe_last_error(
self,
value: Option<Option<String>>,
) -> BlobStorageIntegrationResponseBuilder<SetLastError<S>>where
S::LastError: IsUnset,
Sourcepub fn last_error_at(
self,
value: Option<DateTime<FixedOffset>>,
) -> BlobStorageIntegrationResponseBuilder<SetLastErrorAt<S>>where
S::LastErrorAt: IsUnset,
pub fn last_error_at(
self,
value: Option<DateTime<FixedOffset>>,
) -> BlobStorageIntegrationResponseBuilder<SetLastErrorAt<S>>where
S::LastErrorAt: IsUnset,
Sourcepub fn maybe_last_error_at(
self,
value: Option<Option<DateTime<FixedOffset>>>,
) -> BlobStorageIntegrationResponseBuilder<SetLastErrorAt<S>>where
S::LastErrorAt: IsUnset,
pub fn maybe_last_error_at(
self,
value: Option<Option<DateTime<FixedOffset>>>,
) -> BlobStorageIntegrationResponseBuilder<SetLastErrorAt<S>>where
S::LastErrorAt: IsUnset,
Sourcepub fn created_at(
self,
value: DateTime<FixedOffset>,
) -> BlobStorageIntegrationResponseBuilder<SetCreatedAt<S>>where
S::CreatedAt: IsUnset,
pub fn created_at(
self,
value: DateTime<FixedOffset>,
) -> BlobStorageIntegrationResponseBuilder<SetCreatedAt<S>>where
S::CreatedAt: IsUnset,
Required.
Sourcepub fn updated_at(
self,
value: DateTime<FixedOffset>,
) -> BlobStorageIntegrationResponseBuilder<SetUpdatedAt<S>>where
S::UpdatedAt: IsUnset,
pub fn updated_at(
self,
value: DateTime<FixedOffset>,
) -> BlobStorageIntegrationResponseBuilder<SetUpdatedAt<S>>where
S::UpdatedAt: IsUnset,
Required.